@@ -336,6 +336,9 @@ class fock_space_kron:
         6) self create: scipy sparse matrix
             A list of creation operators for each mode(from 0 to self.modes-1)
         """
+        self.f1 = f1
+        self.f2 = f2
+        
         #1)
         self.modes = f1.modes + f2.modes
 
@@ -411,10 +414,10 @@ class fock_space_kron:
         -------
             sparse matrix
         """
-        if (i<f1.modes):
-             return(sparse.kron(f1.sigmax(i), f2.eye))
+        if (i<self.f1.modes):
+             return(sparse.kron(f1.sigmax(i), self.f2.eye))
         else:
-            return(sparse.kron(f1.eye, f2.sigmax(i-f1.modes)))
+            return(sparse.kron(self.f1.eye, self.f2.sigmax(i-self.f1.modes)))
 
         
     def sigmay(self, i):
@@ -430,10 +433,10 @@ class fock_space_kron:
         -------
             sparse matrix
         """
-        if (i<f1.modes):
-             return(sparse.kron(f1.sigmay(i), f2.eye))
+        if (i<self.f1.modes):
+             return(sparse.kron(self.f1.sigmay(i), self.f2.eye))
         else:
-            return(sparse.kron(f1.eye, f2.sigmay(i-f1.modes)))
+            return(sparse.kron(self.f1.eye, self.f2.sigmay(i-self.f1.modes)))
 
         
     def sigmaz(self, i):
@@ -449,10 +452,10 @@ class fock_space_kron:
         -------
             sparse matrix
         """
-        if (i<f1.modes):
-             return(sparse.kron(f1.sigmaz(i), f2.eye))
+        if (i<self.f1.modes):
+             return(sparse.kron(self.f1.sigmaz(i), self.f2.eye))
         else:
-            return(sparse.kron(f1.eye, f2.sigmaz(i-f1.modes)))
+            return(sparse.kron(self.f1.eye, self.f2.sigmaz(i-self.f1.modes)))
     
     
     def occupations(self,i):
@@ -472,8 +475,8 @@ class fock_space_kron:
             print('the number is out of range')
         else:
             state = np.zeros(self.modes, dtype = int)
-            state[:f1.modes] = f1.occupations(i//f2.dimension)
-            state[f1.modes:] = f2.occupations(i%f2.dimension)
+            state[:self.f1.modes] = self.f1.occupations(i//self.f2.dimension)
+            state[self.f1.modes:] = self.f2.occupations(i%self.f2.dimension)
             return(tuple(state))
         
         
@@ -494,7 +497,7 @@ class fock_space_kron:
             print('incorrect size of an array')
         else:
             s = list(state)
-            return(f1.index(state[:f1.modes]) * f2.dimension + f2.index(state[f1.modes:]))
+            return(self.f1.index(state[:self.f1.modes]) * self.f2.dimension + self.f2.index(state[self.f1.modes:]))
         
 def real_time_solver(psi0, dt, tmax, H, Q):
     """
